6. About — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- previous |
- Umbra 1.0.8 documentation »

# 6. About

Umbra by Thomas Mansencal – 2010 - 2013
Copyright© 2010 - 2013 – Thomas Mansencal – thomas.mansencal@gmail.com
This software is released under terms of GNU GPL V3 license: http://www.gnu.org/licenses/
http://www.thomasmansencal.com/

### Navigation

- index
- modules |
- previous |
- Umbra 1.0.8 documentation »